from illuminate.exceptions import BasicIlluminateException


class BasicManagerException(BasicIlluminateException):
    """Base Manager exception class."""
